@@ -9,7 +9,8 @@ from getmac import get_mac_address as gma
 def inference(img_path, lang):
     try:
         macadd=gma()
-        uniqueadd =["60:e3:2b:34:66:ce"]
+        '''uniqueadd =["60:e3:2b:34:66:ce"]'''
+        uniqueadd=["c0:25:a5:5c:a5:61"]
         if macadd in uniqueadd:
             print("Configured Sucessfully")
             ocr = PaddleOCR(use_angle_cls=True, lang=lang,use_gpu=True)
